/* Elegro Crypto payment styles
----------------------------------------------------------------- */
#modal {
  position: static !important;
  background: none !important;
  overflow: visible;
  padding: 0 !important;
}
#modal #elegro-reset-wrapper {
  margin: 2em 0 0;
}
#modal #elegro-reset-wrapper .elegro-widget {
  padding: 40px 20px 30px;
  margin: 0 !important;
  -webkit-border-radius: 10px;
  -ms-border-radius: 10px;
  border-radius: 10px;
}
#modal .elegro-widget__actions .elegro-widget__button[disabled] {
  color: #ffffff !important;
}

#elegro-reset-wrapper .elegro-widget__coin-selector .vs__actions {
  margin-top: 0;
}

#elegro-reset-wrapper .elegro-widget__button--instant {
  line-height: 1.1em;
}

#elegro-reset-wrapper input {
  margin: 0 !important;
}

#modal .vs__selected,
#modal .vs__search, #modal .vs__search:focus {
  line-height: 42px !important;
  font-size: 1em;
  border: 1px solid transparent;
  border-left: none !important;
  outline: none !important;
  margin: 4px 0 0 0 !important;
  padding: 0 18px !important;
}
#modal .vs__search, #modal .vs__search:focus {
  width: 0;
}

#modal[style*="fixed;"] + .btn-buy,
#modal[style*="position: fixed;"] + .btn-buy {
  display: none;
}

#modal:not(:empty) + #btn-buy,
#modal:not(:empty) ~ #btn-buy {
  display: none;
}

/*# sourceMappingURL=elegro-payment.css.map */
